@@ -29,10 +29,12 @@ from optparse import OptionParser
 import logging
 import logging.handlers
 import traceback
+from datetime import datetime
 
 from os import path
 
 from pytrainer import platform
+from pytrainer.util.date import DateRange
 from upgrade.data import initialize_data
 from environment import Environment
 from record import Record
@@ -41,7 +43,7 @@ from extension import Extension
 from importdata import Importdata
 from plugins import Plugins
 from profile import Profile
-from pytrainer.sport import SportService
+from pytrainer.core.sport import SportService
 from athlete import Athlete
 from stats import Stats
 
@@ -54,8 +56,8 @@ from lib.uc import UC
 
 class pyTrainer:
     def __init__(self,filename = None, data_path = None):
-        #Version constants
-        self.version ="1.9.2-dev"
+        # Based in Django's approach -> http://code.djangoproject.com/svn/django/trunk/django/__init__.py
+        self.version = __import__('pytrainer').get_version()
         #Process command line options
         self.startup_options = self.get_options()
         #Setup logging
@@ -63,7 +65,7 @@ class pyTrainer:
         self.environment.create_directories()
         self.set_logging(self.startup_options.log_level, self.startup_options.log_type)
         logging.debug('>>')
-        logging.debug("PyTrainer version %s" % (self.version))
+        logging.debug("pytrainer version %s" % (self.version))
         self.data_path = data_path
         self.date = Date()
         self.ddbb = None
@@ -99,7 +101,6 @@ class pyTrainer:
         self.windowmain.run()
         logging.debug('<<')
 
-
     def get_options(self):
         '''
         Define usage and accepted options for command line startup
@@ -154,8 +155,14 @@ class pyTrainer:
              logging.info("No active plugins")
         else:
              for plugin in activeplugins:
-                txtbutton = self.plugins.loadPlugin(plugin)
-                self.windowmain.addImportPlugin(txtbutton)
+                # From version 1.10 on all file imports are managed via File -> import wizard
+                # Only showing garmintools_full and garmin-hr in 'File' dropdown
+                plugin_name = os.path.basename(plugin)
+                if (plugin_name == "garmintools_full" or plugin_name == "garmin-hr"):
+                    txtbutton = self.plugins.loadPlugin(plugin)
+                    self.windowmain.addImportPlugin(txtbutton)
+                else:
+                    logging.debug('From version 1.10 on file import plugins are managed via File -> Import. Not displaying plugin ' + plugin_name)
         logging.debug('<<')
 
     def loadExtensions(self):
@@ -236,30 +243,27 @@ class pyTrainer:
              #selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
         elif view=="week":
              logging.debug('week view')
-             date_ini, date_end = self.date.getWeekInterval(date_selected, self.profile.prf_us_system)
+             date_range = DateRange.for_week_containing(date_selected)
              sport = self.windowmain.activeSport
              sport_id = self.record.getSportId(sport)
-             record_list = self.record.getrecordPeriod(date_ini, date_end, sport_id)
-             self.windowmain.actualize_weekview(record_list, date_ini, date_end)
+             record_list = self.record.getrecordPeriod(date_range, sport_id)
+             self.windowmain.actualize_weekview(record_list, date_range)
         elif view=="month":
              logging.debug('month view')
-             date_ini, date_end = self.date.getMonthInterval(date_selected)
+             date_range = DateRange.for_month_containing(date_selected)
              sport = self.windowmain.activeSport
              sport_id = self.record.getSportId(sport)
-#             record_list = self.record.getrecordPeriodSport(date_ini, date_end,sport_id)
-             record_list = self.record.getrecordPeriod(date_ini, date_end, sport_id)
+             record_list = self.record.getrecordPeriod(date_range, sport_id)
              nameMonth, daysInMonth = self.date.getNameMonth(date_selected)
              self.windowmain.actualize_monthview(record_list, nameMonth)
              self.windowmain.actualize_monthgraph(record_list, daysInMonth)
         elif view=="year":
              logging.debug('year view')
-             date_ini, date_end = self.date.getYearInterval(date_selected)
+             date_range = DateRange.for_year_containing(date_selected)
              sport = self.windowmain.activeSport
              sport_id = self.record.getSportId(sport)
-             year = self.date.getYear(date_selected)
-#             record_list = self.record.getrecordPeriodSport(date_ini, date_end,sport_id)
-             record_list = self.record.getrecordPeriod(date_ini, date_end, sport_id)
-             self.windowmain.actualize_yearview(record_list, year)
+             record_list = self.record.getrecordPeriod(date_range, sport_id)
+             self.windowmain.actualize_yearview(record_list, date_selected.year)
              self.windowmain.actualize_yeargraph(record_list)
         elif view=="listview":
             logging.debug('list view')
@@ -273,7 +277,7 @@ class pyTrainer:
         else:
             print "Unknown view %s" % view
         logging.debug('<<')
-
+        
     def refreshRecordGraphView(self, view, id_record=None):
         logging.debug('>>')
         logging.info('Working on '+view+' graph')
@@ -399,8 +403,12 @@ class pyTrainer:
         for plugin in activeplugins_after:
             if plugin not in activeplugins_before:
                 #new active plugin -> need to load plugin
-                txtbutton = self.plugins.loadPlugin(plugin)
-                self.windowmain.addImportPlugin(txtbutton)
+                plugin_name = os.path.basename(plugin)
+                if (plugin_name == "garmintools_full" or plugin_name == "garmin-hr"):
+                    txtbutton = self.plugins.loadPlugin(plugin)
+                    self.windowmain.addImportPlugin(txtbutton)
+                else:
+                    logging.debug('From version 1.10 on file import plugins are managed via File -> Import. Not displaying plugin ' + plugin_name)
         logging.debug('<<')
 
     def setExtensions(self, before, after):
@@ -421,10 +429,9 @@ class pyTrainer:
                 self.windowmain.addExtension(txtbutton)
         logging.debug('<<')
 
-    def newRecord(self,title=None,distance=None,time=None,upositive=None,unegative=None,bpm=None,calories=None,date=None,comment=None,view=None):
+    def newRecord(self,title=None,distance=None,time=None,upositive=None,unegative=None,bpm=None,calories=None,comment=None,view=None):
         logging.debug('>>')
-        if date == None:
-             date = self.date.getDate()
+        date = self.date.getDate()
         self.record.newRecord(date, title, distance, time, upositive, unegative, bpm, calories, comment)
         self.refreshListRecords()
         if view is not None:
