@@ -28,8 +28,8 @@ from lib.ddbb import DDBB
 from lib.xmlUtils import XMLParser
 from lib.date import Date
 from lib.gpx import Gpx
-from pytrainer.equipment import EquipmentService
-from pytrainer.sport import Sport
+from pytrainer.core.equipment import EquipmentService
+from pytrainer.core.sport import Sport
 
 class Record:
 	def __init__(self, sport_service, data_path = None, parent = None):
@@ -46,7 +46,7 @@ class Record:
 	def newRecord(self, date, title=None, distance=None, time=None, upositive=None, unegative=None, bpm=None, calories=None, comment=None):
 		logging.debug('>>')
 		sports = self._sport_service.get_all_sports()
-		self.recordwindow = WindowRecord(self._equipment_service, self.data_path, sports, self, date, title, distance, time, upositive, unegative, bpm, calories, comment)
+		self.recordwindow = WindowRecord(self._equipment_service, self.data_path, sports, self, self.format_date(date), title, distance, time, upositive, unegative, bpm, calories, comment)
 		self.recordwindow.run()
 		logging.debug('<<')
 
@@ -309,17 +309,20 @@ class Record:
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local",
 					"id_record=\"%s\" and records.sport=sports.id_sports" %id_record)
 
+	def format_date(self, date):
+		return date.strftime("%Y-%m-%d")
+
 	def getrecordList(self,date, id_sport=None):
 		logging.debug('--')
 		if not id_sport:
 			# outer join on sport id to workaround bug where sport reference is null on records from GPX import
 			return self.pytrainer_main.ddbb.select("records left outer join sports on records.sport=sports.id_sports",
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local,upositive,unegative",
-					"date=\"%s\" " %date)
+					"date=\"%s\" " %self.format_date(date))
 		else:
 			return self.pytrainer_main.ddbb.select("records,sports",
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local,upositive,unegative",
-					"date=\"%s\" and sports.id_sports=\"%s\" and records.sport=sports.id_sports" %(date,id_sport))
+					"date=\"%s\" and sports.id_sports=\"%s\" and records.sport=sports.id_sports" %(self.format_date(date),id_sport))
 
 	def getLaps(self, id_record):
 		logging.debug('--')
@@ -367,13 +370,15 @@ class Record:
 			record_equipment.append(equipment_item)
 		return record_equipment
 
-	def getrecordPeriod(self,date_ini, date_end, sport=None):
+	def getrecordPeriod(self, date_range, sport=None):
 		#TODO This is essentially the same as getrecordPeriodSport (except date ranges) - need to look at merging the two
+		date_ini = self.format_date(date_range.start_date)
+		date_end = self.format_date(date_range.end_date)
 		tables = "records,sports"
 		if not sport:
-			condition = "date>=\"%s\" and date<\"%s\" and records.sport=sports.id_sports" %(date_ini,date_end)
+			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports" %(date_ini,date_end)
 		else:
-			condition = "date>=\"%s\" and date<\"%s\" and records.sport=sports.id_sports and sports.id_sports=\"%s\"" %(date_ini,date_end, sport)
+			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports and sports.id_sports=\"%s\"" %(date_ini,date_end, sport)
 
 		return self.pytrainer_main.ddbb.select(tables,"date,distance,time,beats,comments,average,calories,maxspeed,maxbeats, sports.name,upositive,unegative", condition)
 
@@ -424,8 +429,13 @@ class Record:
 		return None if sport is None else sport.id
 
 	def getAllrecord(self):
+		"""
+		Retrieve all record data (no lap nor equipment) stored in database. Initially intended for csv export
+		arguments:
+		returns: list of data sorted by date desc"""
 		logging.debug('--')
-		return self.pytrainer_main.ddbb.select("records", "date,distance,time,beats,comments,average,calories")
+		return self.pytrainer_main.ddbb.select("records,sports", "date_time_local,title,sports.name,distance,duration,average,maxspeed,pace,maxpace,beats,maxbeats,calories,upositive,unegative,comments",
+            "sports.id_sports = records.sport","order by date_time_local asc")
 
 	def getAllRecordList(self):
 		logging.debug('--')
@@ -445,13 +455,12 @@ class Record:
 
 	def getRecordDayList(self,date, id_sport=None):
 		logging.debug('>>')
-		year,month,day = date.split("-")
-		logging.debug('Retrieving data for '+year+'.'+month+'.'+day)
+		logging.debug('Retrieving data for ' + str(date))
 		# Why is looking for all days of the same month?
 		if not id_sport:
-			records = self.pytrainer_main.ddbb.select("records","date","date LIKE '"+year+"-"+month+"-%'")
+			records = self.pytrainer_main.ddbb.select("records","date","date LIKE '" +str(date.year)+"-"+date.strftime("%m")+"-%'")
 		else:
-			records = self.pytrainer_main.ddbb.select("records","date","date LIKE \"%s-%s-%%\" and sport=\"%s\"" %(year,month,id_sport))
+			records = self.pytrainer_main.ddbb.select("records","date","date LIKE \"%d-%0.2d-%%\" and sport=\"%s\"" %(date.year,date.month,id_sport))
 		logging.debug('Found '+str(len(records))+' entries')
 		day_list = []
 		for i in records:
